@@ -3,12 +3,9 @@ import requests
 import pprint
 import os
 import glob
-import json
-# from lxml import etree
 from jarvis.db.jsonutils import dumpjson
 import string
-
-# import sys
+from collections import OrderedDict
 
 
 class Api(object):
@@ -88,7 +85,7 @@ class Api(object):
         out = response.json()
         pprint.pprint(out)
         response_code = response.status_code
-        print ('code:',response_code, requests.codes.ok)
+        print("code:", response_code, requests.codes.ok)
         if response_code == requests.codes.created:
             print("status: uploaded.")
             upload_id = out["id"]
@@ -260,8 +257,6 @@ class Api(object):
             params["page"] += 1
         return out
 
-
-
     def upload_blob(self, filepath=""):
         """Upload binary blob files."""
         turl = self.base_url + "/rest/blob/"
@@ -286,7 +281,6 @@ class Api(object):
             response.raise_for_status()
             raise Exception("- error: a problem occurred when uploading blob")
 
-
     def get_all_blobs(self):
         """Download binary blob files."""
         turl = self.base_url + "/rest/blob/"
@@ -297,19 +291,32 @@ class Api(object):
         print("All blob doownload response.status_code", response.status_code)
         return response.json()
 
-    def download_blob(self,filename='CHGTMP', bid="5f6a4bb7ece4b0002de4fb60"):
+    def download_blob(self, save_file=True, bid="5f6a4bb7ece4b0002de4fb60"):
         """Download a binary blob file."""
         turl = self.base_url + "/rest/blob/" + bid + "/"
+        # turl = self.base_url + "/rest/blob/download/" + bid + "/"
         response = requests.get(
             turl, verify=False, auth=(self.username, self.password)
         )
-        resp=json.loads(response.content.decode("utf-8"))['handle']
-        response = requests.get(
-            resp, verify=False, auth=(self.username, self.password))
-        print ('resp',response.json())
-        f = open('tmp','w')
-        f.write(resp)
-        f.close()
+        resp = OrderedDict(response.json())
+        data = requests.get(
+            resp["handle"], verify=False, auth=(self.username, self.password)
+        ).content
+        filename = resp["filename"]
+        if save_file:
+            open(filename, "wb").write(data)
+        print(len(data), len(filename))
+        return filename, data
+
+    def delete_blob(self, bid=""):
+        """Delete a blob by id."""
+        turl = self.base_url + "/rest/blob/" + str(bid) + "/"
+        response = requests.delete(
+            turl, verify=False, auth=(self.username, self.password)
+        )
+        response_code = response.status_code
+        print("delete response_code", response_code)
+        return response_code
 
     def delete_all_blobs(self):
         """Delete binary blob files."""
@@ -381,16 +388,11 @@ class Api(object):
 
 
 # TODO:
-# blob operations
-# Adding certifiates
 # workspace operations
-# Add a url in views:JARVIS-DFT,FF etc.
 # federated vs oai_pmh
-# Make download function work
-# upload_dataa()
 
 
-#"""
+"""
 if __name__ == "__main__":
 
 
@@ -462,4 +464,4 @@ if __name__ == "__main__":
     data = {"query": "testxy"}
     result = a.send_keyword_query(data=data)
     print("result", result)
-#"""
+"""
