@@ -1,22 +1,40 @@
 """Module for analyzing QE outputs."""
 
+from collections import OrderedDict
+
 
 class QEout(object):
     """Module for parsing screen QE output files."""
 
-    def __init__(self, filename):
+    def __init__(self, lines=None, filename="qe.out"):
         """Intialize class with filename."""
         self.filename = filename
-        f = open(filename, "r")
-        lines = f.read().splitlines()
-        f.close()
-        self.lines = lines
+        if lines is None:
+            f = open(filename, "r")
+            lns = f.read().splitlines()
+            f.close()
+            self.lines = lns
+        else:
+            self.lines = lines
+
+    @classmethod
+    def from_dict(self, d={}):
+        """Construct from a dictionary."""
+        return QEout(lines=d["lines"], filename=d["filename"])
+
+    def to_dict(self):
+        """Convert class to a dictionary."""
+        d = OrderedDict()
+        d["lines"] = self.lines
+        d["filename"] = self.filename
+        return d
 
     def get_total_energy(self):
         """Get total energy in Ry."""
         energies = []
         for i in self.lines:
             if "total energy              =" in i:
+                print(i)
                 energy = float(i.split()[-2])
                 energies.append(energy)
         return energies[-1]
